function [thisCalcultedAdjustment,newTotalWeight] = ...
    calculateAdjustmentFirstMode(V,y,CB,ropeLocation,weight,density,...
    x_aw,y_aw,w_avail) 
%%calculateAdjustmentFirstMode is a function that calculates the needed 
%%ballast adjustment in the first mission mode
   
    %The measured weights
    M = weight(1);
    m = [weight(2) weight(3) weight(4) weight(5)];
    
    %Postion of measured weights
    x_m = [ropeLocation(1) ropeLocation(1) -ropeLocation(2) -ropeLocation(2)];
    y_m = [y(1) y(2) y(1) y(2)]/1.5;
       
    %Calucalting weight and buoyancy
    [~,~,m_dif] = calculateWeightBuoyancy(M,V,density);
         
    %Calucalting center of gravity
    CG = calculateCenterOfGravity(M,m,x_m,y_m);

    %The calculate the CG shift
    CG_shift = calculateCenterOfGravityShift(CG,CB);
        
    %Posistion of adjustable weights
    x_a = [x_aw(1) x_aw(2) x_aw(3) x_aw(4)];
    y_a = [y_aw(1) y_aw(2) y_aw(3) y_aw(4)];
        
    %Deviation limits
    x_dev = 0.0001;
    y_dev = 0.0001;

    %Calculation of needed weight adjustment
    m_5 = sym('m_5','positive');
    m_6 = sym('m_6','positive');
    m_7 = sym('m_7','positive');
    m_8 = sym('m_8','positive');    
   if abs(CG_shift(1)) < x_dev && abs(CG_shift(2)) < y_dev
        m_f = m_dif*((CG_shift(1)-x_a(3))/(x_a(1)-x_a(3)));
        m_a = m_dif*((CG_shift(1)-x_a(1))/(x_a(3)-x_a(1)));
        m_5 = m_f/2;
        m_6 = m_f/2;
        m_7 = m_a/2;
        m_8 = m_a/2;
        unroundedCalcultedAdjustment = [m_5 m_6 m_7 m_8];
    elseif abs(CG_shift(1)) >= x_dev && abs(CG_shift(2)) < y_dev
        [solv_m5,solv_m6,solv_m7,solv_m8] = vpasolve(...
            [(m_dif*CG_shift(1))==(m_5*x_a(1))+(m_6*x_a(2))+(m_7*x_a(3))...
            +(m_8*x_a(4)),m_5+m_6+m_7+m_8==m_dif,m_5==m_6,m_7==m_8],...
            [m_5,m_6,m_7,m_8],[m_dif/4,m_dif/4,m_dif/4,m_dif/4]);
        unroundedCalcultedAdjustment = [solv_m5 solv_m6 solv_m7 solv_m8];
    elseif abs(CG_shift(1)) < x_dev && abs(CG_shift(2)) >= y_dev
        [solv_m5,solv_m6,solv_m7,solv_m8] = vpasolve(...
            [(m_dif*CG_shift(2))==(m_5*y_a(1))+(m_6*y_a(2))+(m_7*y_a(3))...
            +(m_8*y_a(4)),m_5+m_6+m_7+m_8==m_dif,...
            m_5==-(x_a(3)/x_a(1))*m_7,m_6==-(x_a(4)/x_a(2))*m_8],...
            [m_5,m_6,m_7,m_8],[m_dif/4,m_dif/4,m_dif/4,m_dif/4]);
        unroundedCalcultedAdjustment = [solv_m5 solv_m6 solv_m7 solv_m8];
    else
        [~,I_max] = max(m);
        [~,I_min] = min(m);
        w_dev = (m(I_max)-m(I_min))/4;
        m_newdif = m_dif-(4*w_dev);
        m_f = (m_newdif*((CG_shift(1)-x_a(3))/(x_a(1)-x_a(3))))/2;
        m_a = (m_newdif*((CG_shift(1)-x_a(1))/(x_a(3)-x_a(1))))/2;
        if CG_shift(1) < 0 && CG_shift(2) < 0
            m_5 = (m_f);
            m_6 = (m_f)+w_dev;
            m_7 = (m_a)+w_dev;
            m_8 = (m_a)+(2*w_dev);
        elseif CG_shift(1) > 0 && CG_shift(2) > 0
            m_5 = (m_f)+(2*w_dev);
            m_6 = (m_f)+w_dev;
            m_7 = (m_a)+w_dev;
            m_8 = (m_a);
        elseif CG_shift(1) < 0 && CG_shift(2) > 0
            m_5 = (m_f)+w_dev;
            m_6 = (m_f);
            m_7 = (m_a)+(2*w_dev);
            m_8 = (m_a)+w_dev;
        elseif CG_shift(1) > 0 && CG_shift(2) < 0
            m_5 = (m_f)+w_dev;
            m_6 = (m_f)+(2*w_dev);
            m_7 = (m_a);
            m_8 = (m_a)+w_dev;
        end
        unroundedCalcultedAdjustment = [m_5 m_6 m_7 m_8];
    end

    calcultedAdjustment = roundOffVector4Elements(...
        unroundedCalcultedAdjustment,10);
    
    %Check if the solution is feasible
    if calcultedAdjustment(1) < 0 || calcultedAdjustment(2) < 0 ...
            || calcultedAdjustment(3) < 0 || calcultedAdjustment(4) < 0
        msgbox({'The found weight adjustment is not feasible.' ...
            'It is not possible to adjust the trim without making the AUV too heavy.' ...
            'Consider reconfiguring the payloads inside the AUV.'}, ...
            'Solution check','modal');
        thisCalcultedAdjustment = [0 0 0 0];
    else
        msgbox('The found weight adjustment is feasible.',...
            'Solution check','modal');
        thisCalcultedAdjustment = calcultedAdjustment;
    end
    
    addedWeight = mappingAdjustments(thisCalcultedAdjustment,w_avail);
    
    %Calculte new total weight with weights added
    newTotalWeight = calculateNewTotalWeight(M,addedWeight);
    
end

