function [newAddedWeight,newTotalWeight] = calculateAdjustmentPreMode(V,...
    totalWeight,density,addedWeight,depthDev,pitchDev,rollDev,w_avail,x_aw)
%%calculateAdjustmentPreMode is a function that calculates the needed 
%%ballast adjustment in the pre mission mode

    %Calucalting weight and buoyancy  
    [~,~,buoyancyError] = calculateWeightBuoyancy(totalWeight,V,density);
    
    %The smallest available weights, which will make the base for some 
    %of the ballast errors
    w_small = w_avail(1);
    
    %Deviation limits
    pitchLimit = 0.5; %Degrees
    rollLimit = 0.1; %Degrees
    depthLimit = [0.1 0.0]; %Meters
    weightLimit = [4*w_small 0.0]; %Kilos
    
    %Desired values
    depthDesired = 0;
    pitchDesired = 0;
    rollDesired = 0;
    
    %Error values
    depthError = depthDesired - depthDev;
    pitchError = pitchDesired - pitchDev;
    rollError = rollDesired - rollDev;
    
    %Calculating the new adjustment
    calcultedAdjustment = weightAdjustmentController(addedWeight,...
        w_small,weightLimit,depthLimit,pitchLimit,rollLimit,depthError,...
        buoyancyError,pitchError,rollError,x_aw);    
    thisCalcultedAdjustment = roundOffVector4Elements(...
        calcultedAdjustment,1000);
    newAddedWeight = mappingAdjustments(thisCalcultedAdjustment,w_avail);
    thisNewAddedWeight = newAddedWeight-addedWeight;
    
    %Calculte new total weight with weights added
    newTotalWeight = calculateNewTotalWeight(totalWeight,...
        thisNewAddedWeight);
end

