function [density] = calculateDensityNoPressure(temperature,salinity)
%calculateDensityNoPressure is a function that calculates the water 
%denisty based on only temperature and salinity

    %Calculation are borrowed from
    %http://www.csgnetwork.com/h2odenscalc.html which has 
    %based its calculations on Millero, F, C. Chen, A Bradshaw, and K. 
    %Schleicher, 1980: A new high pressure equation of state for seawater, 
    %Deep Sea Research, Part A, 27, 255-264. 
    
	%Density based on temperature
	rho = 1000*(1.0-(temperature+288.9414)/(508929.2*(temperature...
        +68.12963))*((temperature-3.9863).^2));
      
	%Density based on temperature and salinity
	A = 0.824493-0.0040899*temperature+0.000076438*temperature.^2 ...
        -0.00000082467*temperature.^3+0.0000000053675*temperature.^4;
	B = -0.005724+0.00010227*temperature-0.0000016546*temperature.^2;
	density = rho+A*salinity+B*salinity.^(3/2)+0.00048314*salinity.^2;
end

