function [avgSalin,avgTemp,avgBuoyDer,avgPitchDer,avgRollDer] = ...
    dataProcessing(salinityDepthData,temperatureDepthData,...
    salinityCtdData,temperatureCtdData,measuredDepthData,...
    commandedDepthData,measuredPitchData,commandedPitchData,...
    revolutionsData,velocityData,rollData)
%%dataProcessing is a function that will process the mission data and
%%determines needed proterties
   
    %Water properties
    depthSalinity = sum(salinityDepthData((length(...
        salinityDepthData)*0.4):(length(salinityDepthData)*0.6)))...
        /((length(salinityDepthData)*0.6)-(length(...
        salinityDepthData)*0.4));
    depthTemperature = sum(temperatureDepthData((length(...
        temperatureDepthData)*0.4):(length(temperatureDepthData)*0.6)))...
        /((length(temperatureDepthData)*0.6)-(length(...
        temperatureDepthData)*0.4));
    
	ctdSalinity = sum(salinityCtdData((length(...
        salinityCtdData)*0.4):(length(salinityCtdData)*0.6)))...
        /((length(salinityCtdData)*0.6)-(length(...
        salinityCtdData)*0.4));
    ctdTemperature = sum(temperatureCtdData((length(...
        temperatureCtdData)*0.4):(length(temperatureCtdData)*0.6)))...
        /((length(temperatureCtdData)*0.6)-(length(...
        temperatureCtdData)*0.4));
    
    avgSalin = (depthSalinity+ctdSalinity)/2;
    avgTemp = (depthTemperature+ctdTemperature)/2;
    
    %Buoyancy deviation based on depth
    first = round(length(commandedDepthData)*0.4);
    last = round(length(commandedDepthData)*0.6);

    depthCheck = zeros(length(commandedDepthData),1); %Array for storing depth values
    i = 2;  %Index for loop
    while i <= length(depthCheck)
      if commandedDepthData(i) == commandedDepthData(i-1)
        depthCheck(i) = commandedDepthData(i)-measuredDepthData(i);
        i = i+1;    %Loop increment
      elseif abs(commandedDepthData(i)-commandedDepthData(i-1)) <= 30
        depthCheck(i) = NaN; 
        i = i+300;    %Skip multiple iterations
      elseif abs(commandedDepthData(i)-commandedDepthData(i-1)) <= 50
        depthCheck(i) = NaN; 
        i = i+400;    %Skip multiple iterations
      elseif abs(commandedDepthData(i)-commandedDepthData(i-1)) <= 100
        depthCheck(i) = NaN; 
        i = i+500;    %Skip multiple iterations
      else
        depthCheck(i) = NaN; 
        i = i+600;    %Skip multiple iterations
      end
    end

    depthCheck(isnan(depthCheck)) = []; %Removing NaNs from array
    buoyancyCheck = depthCheck(first:last); %Removing the zeros before 'first' and after 'last'
    avgBuoyDer = sum(buoyancyCheck)/length(buoyancyCheck); %Calculating the average depth deviation
    
    %Pitch deviation based on depth
    first = round(length(measuredPitchData)*0.4);
    last = round(length(measuredPitchData)*0.6);

    pitchDepthCheck_temp = zeros(length(measuredPitchData),1); %Array for storing pitch values
    i = 3;  %Index for loop
    while i <= length(measuredPitchData)
        if measuredDepthData(i) == measuredDepthData(i-1) ...
                && measuredDepthData(i-1) == measuredDepthData(i-2) %Checking for stable depth samples (der_depth == 0)
            pitchDepthCheck_temp(i) = measuredPitchData(i); %Adding pitch values to array for stable depth samples
        else
            pitchDepthCheck_temp(i) = NaN;
        end
        i = i+1; %Loop increment
    end

    pitchDepthCheck = pitchDepthCheck_temp(first:last); %Removing the zeros before 'first' and after 'last'
    pitchDepthCheck(isnan(pitchDepthCheck)) = []; %Removing NaNs from array
    avgPitchDepthDer = sum(pitchDepthCheck)/length(pitchDepthCheck); %Calculating the average pitch deviation

    %Pitch deviation based on comparing measured and commanded pitch
    pitchMeasComCheck_temp = zeros(length(measuredPitchData),1); %Array for storing pitch values
    i = 3;  %Index for loop
    while i <= length(measuredPitchData)
        pitchMeasComCheck_temp(i) = measuredPitchData(i)...
            -commandedPitchData(i); %Subtracting commanded pitch from measured pitch
        i = i+1; %Loop increment
    end

    pitchMeasComCheck = pitchMeasComCheck_temp(first:last); %Removing the zeros before 'first' and after 'last'
    pitchMeasComCheck(isnan(pitchMeasComCheck)) = []; %Removing NaNs from array
    avgPitchComDer = sum(pitchMeasComCheck)/length(pitchMeasComCheck); %Calculating the average pitch deviation
    
    %Choosing the pitch deviation methode
    avgPitchDer = avgPitchDepthDer;
    %avgPitchDer = avgPitchMeasComDer;
    
    %Roll deviation
    rollCheck = zeros(length(rollData),1); %Array for storing depth values
    i = 1;  %Index for loop
    while i <= length(rollCheck)
        if revolutionsData(i) == 160 %Checking a propeller speed of 160 rpm
            if velocityData(i) > 1.995 && velocityData(i) < 2.005 %Checking a velocity of about 2 m/s
                rollCheck(i) = rollData(i); %Adding roll values to array
            else 
                rollCheck(i) = NaN;
            end
        else
            rollCheck(i) = NaN;
        end
        i = i+1;
    end

    rollCheck(isnan(rollCheck)) = []; %Removing NaNs from array
    avgRollDer = sum(rollCheck)/length(rollCheck); %Calculating the average roll deviation
    
end

