function [calcultedAdjustment] = weightAdjustmentController(addedWeight,...
    w_small,weightDev,depthDev,pitchDev,rollDev,depthError,...
    buoyancyError,pitchError,rollError,x_aw)
%%weightAdjustmentController is a function that determines a suitable
%%ballast adjustment based on weights already used, the depth, 
%weight/buoyancy imbalance, the pitch and roll errors
    
    %The already added weights
    m_1 = addedWeight(1);
    m_2 = addedWeight(2);
    m_3 = addedWeight(3);
    m_4 = addedWeight(4);

    %Postion of point of adjustment
    x_5 = x_aw(1);
    x_7 = x_aw(3);
    
    %The new added weights
    m_5 = 0;
    m_6 = 0;
    m_7 = 0;
    m_8 = 0;
    
    %Calculating the new adjustment
    if depthError <= depthDev(1) && depthError >= depthDev(2) 
        %Depth error within the deviation limits
        w_adjust = w_small;
        
        if abs(pitchError) < pitchDev && abs(rollError) < rollDev
            m_5 = m_1;
            m_6 = m_2;
            m_7 = m_3;
            m_8 = m_4;
        elseif abs(pitchError) < pitchDev && rollError < -rollDev
            if m_1 >= w_small && m_3 >= w_small
                m_5 = m_1 - w_adjust;
                m_6 = m_2 + w_adjust;
                m_7 = m_3 - w_adjust;
                m_8 = m_4 + w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif pitchError < -pitchDev && abs(rollError) < rollDev
            if m_3 >= w_small && m_4 >= w_small
                m_5 = m_1 + w_adjust;
                m_6 = m_2 + w_adjust;
                m_7 = m_3 - w_adjust;
                m_8 = m_4 - w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif abs(pitchError) < pitchDev && rollError > rollDev
            if m_2 >= w_small && m_4 >= w_small
                m_5 = m_1 + w_adjust;
                m_6 = m_2 - w_adjust;
                m_7 = m_3 + w_adjust;
                m_8 = m_4 - w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif pitchError > pitchDev && abs(rollError) < rollDev
            if m_1 >= w_small && m_2 >= w_small
                m_5 = m_1 - w_adjust;
                m_6 = m_2 - w_adjust;
                m_7 = m_3 + w_adjust;
                m_8 = m_4 + w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end 
        elseif pitchError < -pitchDev && rollError < -rollDev
            if m_3 >= w_small
                m_5 = m_1;
                m_6 = m_2 + w_adjust;
                m_7 = m_3 - w_adjust;
                m_8 = m_4;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end 
        elseif pitchError > pitchDev && rollError > rollDev
            if m_2 >= w_small
                m_5 = m_1;
                m_6 = m_2 - w_adjust;
                m_7 = m_3 + w_adjust;
                m_8 = m_4;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end 
        elseif pitchError < -pitchDev && rollError > rollDev
            if m_4 >= w_small
                m_5 = m_1 + w_adjust;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4 - w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif pitchError > pitchDev && rollError < -rollDev
            if m_1 >= w_small
                m_5 = m_1 - w_adjust;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4 + w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end    
        end
        
    elseif depthError < depthDev(1) 
        %According the the depth deviation the vehicle is too light
        if buoyancyError > weightDev(1)
            m_dif = (buoyancyError/4)-(4*w_small);
            m_f = ((abs(x_7)/abs(x_5)+abs(x_7))*m_dif);
            m_a = ((abs(x_5)/abs(x_5)+abs(x_7))*m_dif);	
            w_1 = m_f/2;
            w_2 = m_f/2;
            w_3 = m_a/2;
            w_4 = m_a/2;
            w_adjust = w_small;
        else
            w_1 = 0;
            w_2 = 0;
            w_3 = 0;
            w_4 = 0;
            w_adjust = w_small;
        end
        
        if abs(pitchError) < pitchDev && abs(rollError) < rollDev
            m_5 = m_1 + w_1 + w_adjust;
            m_6 = m_2 + w_2 + w_adjust;
            m_7 = m_3 + w_3 + w_adjust;
            m_8 = m_4 + w_4 + w_adjust;
        elseif abs(pitchError) < pitchDev && rollError < -rollDev
            m_5 = m_1 + w_1;
            m_6 = m_2 + w_2 + w_adjust;
            m_7 = m_3 + w_3;
            m_8 = m_4 + w_4 + w_adjust;
        elseif pitchError < -pitchDev && abs(rollError) < rollDev
            m_5 = m_1 + w_1 + w_adjust;
            m_6 = m_2 + w_2 + w_adjust;
            m_7 = m_3 + w_3;
            m_8 = m_4 + w_4;
        elseif abs(pitchError) < pitchDev && rollError > rollDev
            m_5 = m_1 + w_1 + w_adjust;
            m_6 = m_2 + w_2;
            m_7 = m_3 + w_3 + w_adjust;
            m_8 = m_4 + w_4; 
        elseif pitchError > pitchDev && abs(rollError) < rollDev
            m_5 = m_1 + w_1;
            m_6 = m_2 + w_2;
            m_7 = m_3 + w_3 + w_adjust;
            m_8 = m_4 + w_4 + w_adjust;
        elseif pitchError < -pitchDev && rollError < -rollDev
            m_5 = m_1 + w_1 + w_adjust;
            m_6 = m_2 + w_2 + (2*w_adjust);
            m_7 = m_3 + w_3;
            m_8 = m_4 + w_4 + w_adjust;
        elseif pitchError > pitchDev && rollError > rollDev
            m_5 = m_1 + w_1 + w_adjust;
            m_6 = m_2 + w_2;
            m_7 = m_3 + w_3 + (2*w_adjust);
            m_8 = m_4 + w_4 + w_adjust;
        elseif pitchError < -pitchDev && rollError > rollDev
            m_5 = m_1 + w_1 + (2*w_adjust);
            m_6 = m_2 + w_2 + w_adjust;
            m_7 = m_3 + w_3 + w_adjust;
            m_8 = m_4 + w_4;
        elseif pitchError > pitchDev && rollError < -rollDev
            m_5 = m_1 + w_1;
            m_6 = m_2 + w_2 + w_adjust;
            m_7 = m_3 + w_3 + w_adjust;
            m_8 = m_4 + w_4 + (2*w_adjust); 
        end
        
    elseif depthError > depthDev(2) 
        %According the the depth deviation the vehicle is too heavy
        if buoyancyError < -weightDev(1)
            m_dif = abs((abs(buoyancyError)/4)-(4*w_small));
            m_f = ((abs(x_7))/(abs(x_5)+abs(x_7)))*m_dif;
            m_a = ((abs(x_5))/(abs(x_5)+abs(x_7)))*m_dif;
            w_1 = m_f/2;
            w_2 = m_f/2;
            w_3 = m_a/2;
            w_4 = m_a/2;
            w_adjust = w_small; 
        else
            w_1 = 0;
            w_2 = 0;
            w_3 = 0;
            w_4 = 0;
            w_adjust = w_small;
        end
        
        if abs(pitchError) < pitchDev && abs(rollError) < rollDev
            if m_1 >= w_small && m_2 >= w_small && m_3 >= w_small ...
                    && m_4 >= w_small
                m_5 = m_1 - w_1 - w_adjust;
                m_6 = m_2 - w_2 - w_adjust;
                m_7 = m_3 - w_3 - w_adjust;
                m_8 = m_4 - w_4 - w_adjust;
            else 
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif abs(pitchError) < pitchDev && rollError < -rollDev
            if m_1 >= w_small && m_3 >= w_small
                m_5 = m_1 - w_1 - w_adjust;
                m_6 = m_2 - w_2;
                m_7 = m_3 - w_3 - w_adjust;
                m_8 = m_4 - w_4;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif pitchError < -pitchDev && abs(rollError) < rollDev
            if m_3 >= w_small && m_4 >= w_small
                m_5 = m_1 - w_1;
                m_6 = m_2 - w_2;
                m_7 = m_3 - w_3 - w_adjust;
                m_8 = m_4 - w_4 - w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif abs(pitchError) < pitchDev && rollError > rollDev
            if m_2 >= w_small && m_4 >= w_small
                m_5 = m_1 - w_1;
                m_6 = m_2 - w_2 - w_adjust;
                m_7 = m_3 - w_3;
                m_8 = m_4 - w_4 - w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end 
        elseif pitchError > pitchDev && abs(rollError) < rollDev
            if m_1 >= w_small && m_2 >= w_small
                m_5 = m_1 - w_1 - w_adjust;
                m_6 = m_2 - w_2 - w_adjust;
                m_7 = m_3 - w_3;
                m_8 = m_4 - w_4;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif pitchError < -pitchDev && rollError < -rollDev
            if m_1 >= w_small && m_3 >= (2*w_small) && m_4 >= w_small 
                m_5 = m_1 - w_1 - w_adjust;
                m_6 = m_2 - w_2;
                m_7 = m_3 - w_3 - (2*w_adjust);
                m_8 = m_4 - w_4 - w_adjust;    
            elseif m_3 >= w_small
                m_5 = m_1 - w_1;
                m_6 = m_2 - w_2;
                m_7 = m_3 - w_3 - w_adjust;
                m_8 = m_4 - w_4; 
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4; 
            end
        elseif pitchError > pitchDev && rollError > rollDev
            if m_2 >= (2*w_small) && m_4 >= w_small 
                m_5 = m_1 - w_1;
                m_6 = m_2 - w_2 - (2*w_adjust);
                m_7 = m_3 - w_3;
                m_8 = m_4 - w_4 - w_adjust;    
            elseif m_2 >= w_small
                m_5 = m_1 - w_1;
                m_6 = m_2 - w_2 - w_adjust;
                m_7 = m_3 - w_3;
                m_8 = m_4 - w_4; 
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4; 
            end
        elseif pitchError < -pitchDev && rollError > rollDev
            if m_2 >= w_small && m_3 >= w_small && m_4 >= (2*w_small)
                m_5 = m_1 - w_1;
                m_6 = m_2 - w_2 - w_adjust;
                m_7 = m_3 - w_3 - w_adjust;
                m_8 = m_4 - w_4 - (2*w_adjust);
            elseif m_4 >= w_small
                m_5 = m_1 - w_1;
                m_6 = m_2 - w_2;
                m_7 = m_3 - w_3;
                m_8 = m_4 - w_4 - w_adjust;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end
        elseif pitchError > pitchDev && rollError < -rollDev
            if m_1 >= (2*w_small) && m_2 >= w_small && m_3 >= w_small
                m_5 = m_1 - w_1 - (2*w_adjust);
                m_6 = m_2 - w_2 - w_adjust;
                m_7 = m_3 - w_3 - w_adjust;
                m_8 = m_4 - w_4;
            elseif m_1 >= w_small
                m_5 = m_1 - w_1 - w_adjust;
                m_6 = m_2 - w_2;
                m_7 = m_3 - w_3;
                m_8 = m_4 - w_4;
            else
                m_5 = m_1;
                m_6 = m_2;
                m_7 = m_3;
                m_8 = m_4;
            end           
        end
    end
    
    calcultedAdjustment = [m_5 m_6 m_7 m_8];

end

